@@ -8,7 +8,7 @@ use Carp ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.60_13';
+	$VERSION = '0.68_01';
 }
 
 
@@ -31,11 +31,15 @@ sub my_home {
 
 sub _my_home {
 	my $class = shift;
-	return $ENV{HOME} if defined $ENV{HOME};
+	if ( exists $ENV{HOME} and defined $ENV{HOME} ) {
+		return $ENV{HOME};
+	}
 
 	# This is from the original code, but I'm guessing
 	# it means "login directory" and exists on some Unixes.
-	return $ENV{LOGDIR} if $ENV{LOGDIR};
+	if ( exists $ENV{LOGDIR} and $ENV{LOGDIR} ) {
+		return $ENV{LOGDIR};
+	}
 
 	### More-desperate methods
 
@@ -81,6 +85,13 @@ sub my_videos {
 sub users_home {
 	my ($class, $name) = @_;
 
+	# IF and only if we have getpwuid support, and the
+	# name of the user is our own, shortcut to my_home.
+	# This is needed to handle HOME environment settings.
+	if ( $name eq getpwuid($<) ) {
+		return $class->my_home;
+	}
+
 	SCOPE: {
 		my $home = (getpwnam($name))[7];
 		return $home if $home and -d $home;
